﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using testSample.Resources;

using BxlSDK;
// +++
using Windows.Networking.Proximity;     // for PeerFind, PeerInfomation
using Windows.Networking.Sockets;       // for StreamSocket
using Windows.Networking;
using System.Collections.ObjectModel;
using Windows.Storage.Streams;

using Windows.Storage.Pickers;
using Windows.Storage;
using System.Text;

using System.Threading.Tasks;
using System.Threading;

using Windows.ApplicationModel.Core;
using Windows.ApplicationModel.Activation;

namespace testSample
{
    public partial class MainPage : PhoneApplicationPage
    {
        BxlWinPhoneSDK bxlPrinter;
        
        // Constructor
        public MainPage()
        {
            InitializeComponent();
            bxlPrinter = new BxlWinPhoneSDK();
            // Sample code to localize the ApplicationBar
            //BuildLocalizedApplicationBar();
        }

        
        private class PrinterInfo
        {
            public string DisplayName { get; set; }
            public string HostName { get; set; }
        }
         
        private async void Button_Click(object sender, RoutedEventArgs e)
        {
            PairedList.Items.Clear();

            ObservableCollection<BxlWinPhoneSDK.PairedPrinterInfo> pairedPrinter = await bxlPrinter.GetPairedPrinterList();
            
            foreach (var printer in pairedPrinter)
            {
                PairedList.Items.Add(new PrinterInfo { DisplayName = printer.DisplayName, HostName = printer.HostName });
            }
        }
        
        private void SelectPairedPrinter(object sender, SelectionChangedEventArgs e)
        {
            if (null == PairedList.SelectedItem)
            {
                return;
            }
             
            try
            {
                PrinterInfo printer = PairedList.SelectedItem as PrinterInfo;

                PortName.Text = printer.HostName.Substring(1, printer.HostName.Length - 2);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
        }
        
        private async void PortOpen_Click(object sender, RoutedEventArgs e)
        {
            var ret = await bxlPrinter.ConnectToPrinterAsync(PortName.Text);
           
            if (BXL_SUCCESS != ret)
            {
                MessageBox.Show("Failed to connect printer");
            }
            else
            {
                MessageBox.Show("Success to connect printer");
            }
        }

        private void PortClose_Click(object sender, RoutedEventArgs e)
        {
            bxlPrinter.ClosePrinter();
        }

        private void Write_Click(object sender, RoutedEventArgs e)
        {
            bxlPrinter.SetCharacterSet(BXL_CS_WPC1252);

            bxlPrinter.PrintText("Left Default\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("Center, FontB\n", BXL_ALIGNMENT_CENTER, BXL_FT_FONTB, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("Right, FontC\n", BXL_ALIGNMENT_RIGHT, BXL_FT_FONTC, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);

            bxlPrinter.PrintText("Center, Bold, Default\n", BXL_ALIGNMENT_CENTER, BXL_FT_BOLD | BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("Center, Bold, FontB\n", BXL_ALIGNMENT_CENTER, BXL_FT_FONTB | BXL_FT_BOLD, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("Center, Bold, FontC\n", BXL_ALIGNMENT_CENTER, BXL_FT_BOLD | BXL_FT_FONTC, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);

            bxlPrinter.PrintText("Left, Underline\n", BXL_ALIGNMENT_LEFT, BXL_FT_UNDERLINE | BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("Right, Reverse\n", BXL_ALIGNMENT_RIGHT, BXL_FT_REVERSE | BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);

            bxlPrinter.PrintText("Left, Default, 0W 0H\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("Left, Default, 1W 0H\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_1WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("Left, Default, 0W 1H\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_1HEIGHT);
            bxlPrinter.PrintText("Left, Default, 1W 1H\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_1WIDTH | BXL_TS_1HEIGHT);
        }

        private async void Read_Click(object sender, RoutedEventArgs e)
        {
            Int32 status = await bxlPrinter.CheckPrinterStatusAsync();
            string strStatus;

            if ((status & BXL_STS_COVEROPEN) != 0)
            {
                strStatus = "Cover : Open";
            }
            else
            {
                strStatus = "Cover : Close";
            }

            if ((status & BXL_STS_PAPEREMPTY) != 0)
            {
                strStatus += "  Paper : Empty";
            }
            else
            {
                strStatus += "  Paper : OK";
            }

            MessageBox.Show(strStatus);

            Int32 power = await bxlPrinter.CheckPowerAsync();
            string strPower;

            if (power == BXL_PWR_FULL)
                strPower = "Battery : Full. 75~100%";
            else if (power == BXL_PWR_HIGH)
                strPower = "Battery : High. 50~75%";
            else if (power == BXL_PWR_MIDDLE)
                strPower = "Battery : Middle. 10~50%";
            else if (power == BXL_PWR_LOW)
                strPower = "Battery : Low. under 10%";
            else
                strPower = "Failed to check battery.";

            MessageBox.Show(strPower);
        }
 
        CoreApplicationView view = CoreApplication.GetCurrentView();
        
        private async void Image_Click(object sender, RoutedEventArgs e)
        {
            FileOpenPicker imgPicker = new FileOpenPicker();
            imgPicker.ViewMode = PickerViewMode.Thumbnail;
            imgPicker.SuggestedStartLocation = PickerLocationId.PicturesLibrary;
            imgPicker.FileTypeFilter.Add(".bmp");
            imgPicker.FileTypeFilter.Add(".jpeg");
            imgPicker.FileTypeFilter.Add(".jpg");
            imgPicker.FileTypeFilter.Add(".gif");

            imgPicker.PickSingleFileAndContinue();

            view.Activated += PrintImage;
        }

        private async void PrintImage(CoreApplicationView sender, IActivatedEventArgs args1)
        {
            FileOpenPickerContinuationEventArgs args = args1 as FileOpenPickerContinuationEventArgs;

            if (args != null)
            {
                if (args.Files.Count == 0) return;

                view.Activated -= PrintImage;

                try
                {
                    Int32 ret;

                    ret = await bxlPrinter.PrintImage(args.Files[0].Path, 300, BXL_ALIGNMENT_CENTER, 50);

                    if (BXL_SUCCESS != ret)
                    {
                        MessageBox.Show("Failed to print image.");
                    }
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message);
                }
            }
        }

        private async void MSRStart_Click(object sender, RoutedEventArgs e)
        {             
            try
            {
                Task<Int32> task = bxlPrinter.MSRReadReadyAsync();
                await task;

                if (BXL_SUCCESS != task.Result)
                {
                    return;
                }

                byte[] track1 = new byte[120];
                byte[] track2 = new byte[120];
                byte[] track3 = new byte[120];

                Int32 ret = bxlPrinter.MSRReadTrack(ref track1, ref track2, ref track3);

                if (BXL_MSR_DATAEMPTY == ret)
                {
                    MessageBox.Show("MSR DATA EMPTY");
                    return;
                }


                string str1 = string.Format(" track1 = {0}",
                                            Encoding.UTF8.GetString(track1, 0, track1.Length));
                string str2 = string.Format(" track2 = {0}",
                                            Encoding.UTF8.GetString(track2, 0, track2.Length));
                string str3 = string.Format(" track3 = {0}",
                                            Encoding.UTF8.GetString(track3, 0, track3.Length));
                MessageBox.Show(str1);
                MessageBox.Show(str2);
                MessageBox.Show(str3);

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }   
        }

        private async void MSRCancel_Click(object sender, RoutedEventArgs e)
        {
            await bxlPrinter.MSRReadCancel();
        }

        private void MSRRead_Click(object sender, RoutedEventArgs e)
        {
            byte[] track1 = new byte[120];
            byte[] track2 = new byte[120];
            byte[] track3 = new byte[120];

             Int32 ret = bxlPrinter.MSRReadTrack(ref track1, ref track2, ref track3);

            if (BXL_MSR_DATAEMPTY == ret)
            {
                MessageBox.Show("MSR DATA EMPTY");
                return;
            }

            string str1 = string.Format(" track1 = {0}",
                                        Encoding.UTF8.GetString(track1, 0, track1.Length));
            string str2 = string.Format(" track2 = {0}",
                                        Encoding.UTF8.GetString(track2, 0, track2.Length));
            string str3 = string.Format(" track3 = {0}",
                                        Encoding.UTF8.GetString(track3, 0, track3.Length));
            MessageBox.Show(str1);
            MessageBox.Show(str2);
            MessageBox.Show(str3);
        }  

        private void Feed_Click(object sender, RoutedEventArgs e)
        {
            bxlPrinter.LineFeed(6);
        }

        private void Barcode_Click(object sender, RoutedEventArgs e)
        {
            byte[] bytes = new byte[12] { 0x31, 0x32, 0x33, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x30, 0x31, 0x32 };

            bxlPrinter.PrintText("UPCA\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_UPCA, 50, 2, BXL_ALIGNMENT_LEFT, BXL_BC_TEXT_BELOW);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_UPCA, 70, 3, BXL_ALIGNMENT_CENTER, BXL_BC_TEXT_BELOW);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_UPCA, 30, 2, BXL_ALIGNMENT_RIGHT, BXL_BC_TEXT_BELOW);

            bxlPrinter.PrintText("UPCE\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_UPCE, 50, 2, BXL_ALIGNMENT_LEFT, BXL_BC_TEXT_BELOW);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_UPCE, 30, 3, BXL_ALIGNMENT_CENTER, BXL_BC_TEXT_NONE);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_UPCE, 70, 2, BXL_ALIGNMENT_RIGHT, BXL_BC_TEXT_NONE);

            bxlPrinter.PrintText("EAN13\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_EAN13, 50, 2, BXL_ALIGNMENT_LEFT, BXL_BC_TEXT_ABOVE);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_EAN13, 70, 2, BXL_ALIGNMENT_CENTER, BXL_BC_TEXT_ABOVE);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_EAN13, 50, 3, BXL_ALIGNMENT_RIGHT, BXL_BC_TEXT_ABOVE);

            bxlPrinter.PrintText("JAN13\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_JAN13, 50, 2, BXL_ALIGNMENT_LEFT, BXL_BC_TEXT_BELOW);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_JAN13, 70, 4, BXL_ALIGNMENT_CENTER, BXL_BC_TEXT_BELOW);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_JAN13, 30, 2, BXL_ALIGNMENT_RIGHT, BXL_BC_TEXT_BELOW);

            byte[] bytes1 = new byte[8] { 0x31, 0x32, 0x33, 0x34, 0x34, 0x35, 0x36, 0x38 };
            bxlPrinter.PrintText("EAN8\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes1, BXL_BCS_EAN8, 50, 2, BXL_ALIGNMENT_LEFT, BXL_BC_TEXT_NONE);
            bxlPrinter.PrintBarcode(bytes1, BXL_BCS_EAN8, 70, 2, BXL_ALIGNMENT_CENTER, BXL_BC_TEXT_NONE);
            bxlPrinter.PrintBarcode(bytes1, BXL_BCS_EAN8, 60, 3, BXL_ALIGNMENT_RIGHT, BXL_BC_TEXT_NONE);

            bxlPrinter.PrintText("JAN8\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes1, BXL_BCS_JAN8, 50, 2, BXL_ALIGNMENT_LEFT, BXL_BC_TEXT_BELOW);
            bxlPrinter.PrintBarcode(bytes1, BXL_BCS_JAN8, 50, 4, BXL_ALIGNMENT_CENTER, BXL_BC_TEXT_BELOW);
            bxlPrinter.PrintBarcode(bytes1, BXL_BCS_JAN8, 50, 3, BXL_ALIGNMENT_RIGHT, BXL_BC_TEXT_BELOW);

            byte[] bytes2 = new byte[12] { 0x31, 0x32, 0x33, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x30, 0x31, 0x32 };

            bxlPrinter.PrintText("Code 39\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_CODE39, 50, 2, BXL_ALIGNMENT_LEFT, BXL_BC_TEXT_ABOVE);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_CODE39, 70, 3, BXL_ALIGNMENT_CENTER, BXL_BC_TEXT_ABOVE);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_CODE39, 50, 4, BXL_ALIGNMENT_RIGHT, BXL_BC_TEXT_ABOVE);

            bxlPrinter.PrintText("ITF\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_ITF, 50, 2, BXL_ALIGNMENT_LEFT, BXL_BC_TEXT_NONE);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_ITF, 30, 3, BXL_ALIGNMENT_CENTER, BXL_BC_TEXT_NONE);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_ITF, 70, 4, BXL_ALIGNMENT_RIGHT, BXL_BC_TEXT_NONE);

            bxlPrinter.PrintText("Codebar\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_CODABAR, 50, 2, BXL_ALIGNMENT_LEFT, BXL_BC_TEXT_BELOW);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_CODABAR, 40, 3, BXL_ALIGNMENT_CENTER, BXL_BC_TEXT_BELOW);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_CODABAR, 70, 2, BXL_ALIGNMENT_RIGHT, BXL_BC_TEXT_BELOW);

            bxlPrinter.PrintText("Code 93\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_CODE93, 50, 2, BXL_ALIGNMENT_LEFT, BXL_BC_TEXT_ABOVE);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_CODE93, 60, 2, BXL_ALIGNMENT_CENTER, BXL_BC_TEXT_ABOVE);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_CODE93, 70, 2, BXL_ALIGNMENT_RIGHT, BXL_BC_TEXT_ABOVE);

            bxlPrinter.PrintText("Code 128\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_CODE128, 50, 2, BXL_ALIGNMENT_LEFT, BXL_BC_TEXT_NONE);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_CODE128, 50, 2, BXL_ALIGNMENT_CENTER, BXL_BC_TEXT_NONE);
            bxlPrinter.PrintBarcode(bytes2, BXL_BCS_CODE128, 50, 2, BXL_ALIGNMENT_RIGHT, BXL_BC_TEXT_NONE);

            bxlPrinter.LineFeed(5);
        }

        private void Sample_Click(object sender, RoutedEventArgs e)
        {
            bxlPrinter.SetCharacterSet(BXL_CS_WPC1251);
            bxlPrinter.SetInterCharSet(BXL_ICS_USA);

            bxlPrinter.PrintText("Receipt\n", BXL_ALIGNMENT_CENTER, BXL_FT_BOLD | BXL_FT_UNDERLINE, BXL_TS_1WIDTH | BXL_TS_1HEIGHT);
            bxlPrinter.PrintText("\n\n", BXL_ALIGNMENT_CENTER, BXL_FT_BOLD | BXL_FT_UNDERLINE, BXL_TS_1WIDTH | BXL_TS_1HEIGHT);

            bxlPrinter.PrintText("------------------------------\n", BXL_ALIGNMENT_CENTER, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText(" Apple      3             $3.0\n", BXL_ALIGNMENT_CENTER, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText(" Cola       1             $1.2\n", BXL_ALIGNMENT_CENTER, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText(" Milk       2             $1.8\n", BXL_ALIGNMENT_CENTER, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText(" Juice      1             $2.0\n", BXL_ALIGNMENT_CENTER, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("------------------------------\n", BXL_ALIGNMENT_CENTER, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText(" Total                    $8.0\n", BXL_ALIGNMENT_CENTER, BXL_FT_BOLD, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText(" Cash                     $8.0\n", BXL_ALIGNMENT_CENTER, BXL_FT_BOLD, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("                          $0.0\n", BXL_ALIGNMENT_CENTER, BXL_FT_BOLD, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);

            //////////////////////////////////////////////////////////////////////////
            //Set multi attribute in one line.
            bxlPrinter.PrintText("Test", BXL_ALIGNMENT_CENTER, BXL_FT_BOLD, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("BBB", BXL_ALIGNMENT_CENTER, BXL_FT_FONTB | BXL_FT_BOLD, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("CCC", BXL_ALIGNMENT_CENTER, BXL_FT_FONTB | BXL_FT_REVERSE, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("DDD", BXL_ALIGNMENT_CENTER, BXL_FT_BOLD | BXL_FT_UNDERLINE, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("\n", BXL_ALIGNMENT_CENTER, BXL_FT_BOLD | BXL_FT_UNDERLINE, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);

            bxlPrinter.PrintText("ABCDEFabcdef\n", BXL_ALIGNMENT_CENTER, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("ABCDEFabcdef\n", BXL_ALIGNMENT_CENTER, BXL_FT_FONTB, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintText("ABCDEFabcdef\n", BXL_ALIGNMENT_CENTER, BXL_FT_FONTC, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);


            bxlPrinter.LineFeed(5);
        }

        private void Barcode2_Click(object sender, RoutedEventArgs e)
        {
            byte[] bytes = new byte[12] { 0x31, 0x32, 0x33, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x30, 0x31, 0x32 };

            bxlPrinter.PrintText("PDF417\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_PDF417, 0, 2, BXL_ALIGNMENT_LEFT, 0);

            bxlPrinter.PrintText("QRCODE\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_QRCODE_MODEL1, 0, 2, BXL_ALIGNMENT_LEFT, 0);

            bxlPrinter.PrintText("QRCODE\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_QRCODE_MODEL2, 0, 2, BXL_ALIGNMENT_LEFT, 0);

            bxlPrinter.PrintText("DATAMATRIX\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_DATAMATRIX, 0, 2, BXL_ALIGNMENT_LEFT, 0);

            bxlPrinter.PrintText("MAXICODE\n", BXL_ALIGNMENT_LEFT, BXL_FT_DEFAULT, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.PrintBarcode(bytes, BXL_BCS_MAXICODE_MODE4, 0, 2, BXL_ALIGNMENT_LEFT, 0);


            bxlPrinter.LineFeed(5);
        }

        private async void Direct_Click(object sender, RoutedEventArgs e)
        {
            byte[] bytes = new byte[3] { 0x1d, 0x49, 67 };  // GS I
            byte[] ReadBuf = new byte[20];


            ReadBuf = await bxlPrinter.DirectIOAsync(bytes, 20);

            if (null != ReadBuf)
            {
                MessageBox.Show(Encoding.UTF8.GetString(ReadBuf, 1, ReadBuf.Length - 2));
            }     
        }

        private async void SCRPowerUP_Click(object sender, RoutedEventArgs e)
        {
            BxlWinPhoneSDK.SCRData scrData;

            scrData = await bxlPrinter.ScrPowerUp();

            if (0x00 != scrData.ResponseS)
            {
                MessageBox.Show("ScrPowerUp fail.");
                return;
            }

            MessageBox.Show("Success SCR Power UP.");
        }

        private async void SCRPowerDown_Click(object sender, RoutedEventArgs e)
        {
            byte ResponseS = 0xff;

            ResponseS = await bxlPrinter.ScrPowerDown();

            if (0x00 != ResponseS)
            {
                MessageBox.Show("ScrPowerDown fail.");
                return;
            }

            MessageBox.Show("Success SCR Power Down.");
        }

        private async void SCRStatus_Click(object sender, RoutedEventArgs e)
        {
            BxlWinPhoneSDK.SCRStatus scrStatus;

            scrStatus = await bxlPrinter.ScrCheckStatus();

            if (0x00 != scrStatus.ResponseS)
            {
                MessageBox.Show("ScrCheckStatus fail.");
                return;
            }

            string strStatus;

            if ((scrStatus.status & 0x03) == BXL_SCR_STS_5V)
            {
                strStatus = "Power : 5V,";
            }
            else if ((scrStatus.status & 0x03) == BXL_SCR_STS_3V)
            {
                strStatus = "Power : 3V,";
            }
            else
            {
                strStatus = "Power : 1.8V,";
            }

            if ((scrStatus.status & BXL_SCR_STS_POWERED) != 0)
            {
                strStatus += " Card powered,";
            }
            else
            {
                strStatus += " Card not powered,";
            }

            if ((scrStatus.status & BXL_SCR_STS_INSERTED) != 0)
            {
                strStatus += " Card inserted.";
            }
            else
            {
                strStatus += " Card not inserted.";
            }

            MessageBox.Show(strStatus);
        }

        private async void SmartCard_Click(object sender, RoutedEventArgs e)
        {
            byte ResponseS = 0xff;

            ResponseS = await bxlPrinter.ScrSelectCard(BXL_SCR_SMARTCARD);

            if (0x30 != ResponseS)
            {
                MessageBox.Show("Failed to select smart card.");
                return;
            }

            MessageBox.Show("Success to select smart card.");
        }

        private async void SAM1_Click(object sender, RoutedEventArgs e)
        {
            byte ResponseS = 0xff;

            ResponseS = await bxlPrinter.ScrSelectCard(BXL_SCR_SAM1);

            if (0x31 != ResponseS)
            {
                MessageBox.Show("Failed to select smart card.");
                return;
            }

            MessageBox.Show("Success to select smart card.");
        }

        private async void SAM2_Click(object sender, RoutedEventArgs e)
        {
            byte ResponseS = 0xff;

            ResponseS = await bxlPrinter.ScrSelectCard(BXL_SCR_SAM2);

            if (0x32 != ResponseS)
            {
                MessageBox.Show("Failed to select smart card.");
                return;
            }

            MessageBox.Show("Success to select smart card.");
        }

        private void PageSample_Click(object sender, RoutedEventArgs e)
        {
            bxlPrinter.InitializePrinter();
            bxlPrinter.SelectPageMode(true);
            bxlPrinter.SetPrintAreaInPM(0, 0, 416, 416);
            bxlPrinter.SetPrintDirectionInPM(BXL_PD_TOP_TO_BOTTOM);

            string barCode = "1234567890123";

            bxlPrinter.SetVerticalPositionInPM(70);
            bxlPrinter.SetHorizontalPositionInPM(5);

            bxlPrinter.PrintBarcode(barCode, BXL_BCS_CODE93, 50, 2, BXL_ALIGNMENT_LEFT, BXL_BC_TEXT_NONE);

            bxlPrinter.SetVerticalPositionInPM(155);
            bxlPrinter.SetHorizontalPositionInPM(80);
            bxlPrinter.PrintText(barCode, BXL_ALIGNMENT_CENTER, BXL_FT_DEFAULT,
                                BXL_TS_0WIDTH | BXL_TS_0HEIGHT);

            bxlPrinter.SetVerticalPositionInPM(200);
            bxlPrinter.SetHorizontalPositionInPM(0);
            bxlPrinter.PrintText("Name :", BXL_ALIGNMENT_CENTER, BXL_ExFT_CHINA_FONTB,
                                BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.SetVerticalPositionInPM(200);
            bxlPrinter.SetHorizontalPositionInPM(90);

            bxlPrinter.PrintText(" Frank  ", BXL_ALIGNMENT_LEFT, BXL_ExFT_CHINA_FONTA |
                                BXL_FT_UNDERTHICK | BXL_FT_BOLD, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.SetVerticalPositionInPM(200);
            bxlPrinter.SetHorizontalPositionInPM(180);
            bxlPrinter.PrintText("Sex  :", BXL_ALIGNMENT_CENTER, BXL_ExFT_CHINA_FONTA |
                                BXL_TS_0WIDTH, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.SetVerticalPositionInPM(200);
            bxlPrinter.SetHorizontalPositionInPM(260);
            bxlPrinter.PrintText("  male   ", BXL_ALIGNMENT_LEFT, BXL_ExFT_CHINA_FONTA |
                                BXL_FT_UNDERTHICK | BXL_FT_BOLD, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);

            bxlPrinter.SetVerticalPositionInPM(250);
            bxlPrinter.SetHorizontalPositionInPM(0);
            bxlPrinter.PrintText("Age  :", BXL_ALIGNMENT_CENTER, BXL_ExFT_CHINA_FONTA,
                                BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.SetVerticalPositionInPM(250);
            bxlPrinter.SetHorizontalPositionInPM(90);
            bxlPrinter.PrintText("  30  ", BXL_ALIGNMENT_CENTER, BXL_ExFT_CHINA_FONTA |
                                BXL_FT_UNDERTHICK | BXL_FT_BOLD, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.SetVerticalPositionInPM(250);
            bxlPrinter.SetHorizontalPositionInPM(180);
            bxlPrinter.PrintText("City :", BXL_ALIGNMENT_CENTER, BXL_ExFT_CHINA_FONTA |
                                BXL_TS_0WIDTH, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);
            bxlPrinter.SetVerticalPositionInPM(250);
            bxlPrinter.SetHorizontalPositionInPM(260);
            bxlPrinter.PrintText("  Seoul  ", BXL_ALIGNMENT_CENTER, BXL_ExFT_CHINA_FONTA |
                                BXL_FT_UNDERTHICK | BXL_FT_BOLD, BXL_TS_0WIDTH | BXL_TS_0HEIGHT);


            bxlPrinter.SetVerticalPositionInPM(360);
            bxlPrinter.SetHorizontalPositionInPM(60);
            bxlPrinter.PrintText("abcdefgHIJK-123", BXL_ALIGNMENT_CENTER, BXL_FT_DEFAULT,
                                BXL_TS_0WIDTH | BXL_TS_0HEIGHT);

            bxlPrinter.PrintDataInPM();

            bxlPrinter.LineFeed(2);
        }

        private void PageMode_Click(object sender, RoutedEventArgs e)
        {
            bxlPrinter.SelectPageMode(true);
        }

        private void LabelMode_Click(object sender, RoutedEventArgs e)
        {
            bxlPrinter.SelectLabelMode(true);
        }

        private void Calibration_Click(object sender, RoutedEventArgs e)
        {
            bxlPrinter.AutoCalibration();
        }



        // Sample code for building a localized ApplicationBar
        //private void BuildLocalizedApplicationBar()
        //{
        //    // Set the page's ApplicationBar to a new instance of ApplicationBar.
        //    ApplicationBar = new ApplicationBar();

        //    // Create a new button and set the text value to the localized string from AppResources.
        //    ApplicationBarIconButton appBarButton = new ApplicationBarIconButton(new Uri("/Assets/AppBar/appbar.add.rest.png", UriKind.Relative));
        //    appBarButton.Text = AppResources.AppBarButtonText;
        //    ApplicationBar.Buttons.Add(appBarButton);

        //    // Create a new menu item with the localized string from AppResources.
        //    ApplicationBarMenuItem appBarMenuItem = new ApplicationBarMenuItem(AppResources.AppBarMenuItemText);
        //    ApplicationBar.MenuItems.Add(appBarMenuItem);
        //}
    }
}